# disable nautilus support until it's fixed upstream
# (see https://github.com/tristanheaven/gtkhash/issues/139)
%bcond_with nautilus

Name:           gtkhash
Version:        1.5
Release:        %mkrel 3
Summary:        GTK+ utility for computing message digests or checksums
Group:          Graphical desktop/GNOME
License:        GPLv2+
URL:            https://github.com/tristanheaven/gtkhash
Source0:        https://github.com/tristanheaven/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         fix-msgfmt-keyword-use-space.patch

BuildRequires:  appstream-util
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  meson
BuildRequires:  mhash-devel
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libb2)
BuildRequires:  pkgconfig(libgcrypt)
%if %with nautilus
BuildRequires:  pkgconfig(libnautilus-extension-4)
%endif
BuildRequires:  pkgconfig(libcaja-extension)
BuildRequires:  pkgconfig(libnemo-extension)
BuildRequires:  pkgconfig(thunarx-3)

Provides:       gtkhash3 = %{version}-%{release}

%description
GtkHash is a GTK+ utility for computing message digests or checksums.
Currently supported hash functions include:
* MD2, MD4 and MD5
* SHA1, SHA224, SHA256, SHA384 and SHA512,
* RIPEMD128, RIPEMD160, RIPEMD256 and RIPEMD320
* TIGER128, TIGER160 and TIGER192
* HAVAL128-3, HAVAL160-3, HAVAL192-3, HAVAL224-3 and HAVAL256-3
* SNEFRU128 and SNEFRU256
* ADLER32, CRC32, GOST and WHIRLPOOL

This package contains the GTK+3 version of the program.

#----------------------------------------------------------------------------

%package        nautilus
Summary:        GtkHash extension for nautilus
Group:          Graphical desktop/GNOME
Requires:       nautilus
Requires:       %{name} >= %{version}-%{release}
Requires:       GConf2

%description    nautilus
GtkHash extension for the nautilus file manger. It adds adds an additional tab
called "Digests" to the file properties dialog.

#----------------------------------------------------------------------------

%package        thunar
Summary:        GtkHash extension for Thunar
Group:          Graphical desktop/Xfce
Requires:       thunar
Requires:       %{name} >= %{version}-%{release}

%description    thunar
GtkHash extension for the Thunar file manger. It adds adds an additional tab
called "Digests" to the file properties dialog.

#----------------------------------------------------------------------------

%package        nemo
Summary:        GtkHash extension for Nemo
Group:          Graphical desktop/Cinnamon
Requires:       nemo
Requires:       %{name} >= %{version}-%{release}

%description    nemo
GtkHash extension for the Nemo file manger. It adds adds an additional tab
called "Digests" to the file properties dialog.

#----------------------------------------------------------------------------

%package        caja
Summary:        GtkHash extension for Caja
Group:          Graphical desktop/MATE
Requires:       caja
Requires:       %{name} >= %{version}-%{release}

%description    caja
GtkHash extension for the Caja file manger. It adds adds an additional tab
called "Digests" to the file properties dialog.

#----------------------------------------------------------------------------

%prep
%autosetup -p1

%build
./autogen.sh
%configure \
  --with-gtk=3.0 \
  --enable-linux-crypto \
  --enable-gcrypt \
  --enable-glib-checksums \
  --enable-mhash \
  --enable-thunar \
%if %with nautilus
  --enable-nautilus \
%else
  --disable-nautilus \
%endif
  --enable-nemo \
  --enable-caja \
  --disable-schemas-compile

%make_build

%install
%make_install

%find_lang %{name}

# generic
find %{buildroot} -name '*.la' -delete

appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.metainfo.xml
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.appdata.xml

%files -f %{name}.lang
%license COPYING
%doc AUTHORS NEWS
%{_bindir}/%{name}
%{_datadir}/applications/org.%{name}.%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.%{name}.gschema.xml
%{_datadir}/glib-2.0/schemas/org.%{name}.plugin.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.%{name}.%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/org.%{name}.%{name}.svg
%{_metainfodir}/org.%{name}.%{name}.appdata.xml

%if %with nautilus
%files nautilus
%{_libdir}/nautilus/extensions-3.0/libgtkhash-properties-nautilus.so
%{_metainfodir}/org.gtkhash.nautilus.metainfo.xml
%endif

%files thunar
%{_libdir}/thunarx-3/libgtkhash-properties-thunar.so
%{_metainfodir}/org.gtkhash.thunar.metainfo.xml

%files nemo
%{_libdir}/nemo/extensions-3.0/libgtkhash-properties-nemo.so
%{_metainfodir}/org.gtkhash.nemo.metainfo.xml

%files caja
%{_libdir}/caja/extensions-2.0/libgtkhash-properties-caja.so
%{_datadir}/caja/extensions/libgtkhash-properties-caja.caja-extension
%{_metainfodir}/org.gtkhash.caja.metainfo.xml


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 1.5-3.mga10
+ Revision: 2228160
- Mageia 10 Mass Rebuild

* Tue Sep 24 2024 daviddavid <daviddavid> 1.5-2.mga10
+ Revision: 2101027
- add debian patch to fix build

* Thu Nov 03 2022 ghibo <ghibo> 1.5-1.mga9
+ Revision: 1902092
- Revert bcond condition to effectively disable nautilus
- Update to release 1.5.
- Update nautilus BR to nautilus-extension-4.
- Disable nautilus support until it's fixed upstream.

* Tue Apr 05 2022 umeabot <umeabot> 1.4-2.mga9
+ Revision: 1844381
- Mageia 9 Mass Rebuild

* Thu Dec 24 2020 daviddavid <daviddavid> 1.4-1.mga8
+ Revision: 1663456
- initial package gtkhash (mga#27913)

